@@ -19,7 +19,6 @@ class RoutesPlugin(Plugin):
         logger.info('Started Routes Plugin...')
 
         routes_path_list = self.registry_hive.get_control_sets(ROUTES_PATH)
-
-        return get_subkey_values_from_list(self.registry_hive, routes_path_list, as_json=self.as_json)
+        self.entries = get_subkey_values_from_list(self.registry_hive, routes_path_list, as_json=self.as_json)
 
 
